@@ -120,6 +120,11 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$layer = $wine;
 		}
+		else
+		{
+			// Report virtualization
+			$layer = phodevi::read_property('system', 'virtualized-mode');
+		}
 
 		return $layer;
 	}
@@ -192,6 +197,25 @@ class phodevi_system extends phodevi_device_interface
 				}
 			}
 		}
+		else if(phodevi::is_hurd())
+		{
+			// Very rudimentary Hurd filesystem detection support but works for at least a clean Debian GNU/Hurd EXT2 install
+			if(pts_client::executable_in_path('mount'))
+			{
+				$mount = shell_exec('mount 2>&1');
+
+				if(($start = strpos($mount, 'on / type')) != false)
+				{
+					$fs = substr($mount, $start + 10);
+					$fs = substr($fs, 0, strpos($fs, ' '));
+
+					if(substr($fs, -2) == 'fs')
+					{
+						$fs = substr($fs, 0, -2);
+					}
+				}
+			}
+		}
 		else if(phodevi::is_linux() || phodevi::is_solaris())
 		{
 			$fs = trim(shell_exec('stat ' . pts_client::test_install_root_path() . ' -L -f -c %T 2> /dev/null'));
@@ -222,58 +246,49 @@ class phodevi_system extends phodevi_device_interface
 						}
 					}
 					break;
-				case 'UNKNOWN (0x9123683e)':
-					// 0x9123683e is the superblock for Btrfs
-					$fs = 'Btrfs';
-					break;
-				case 'UNKNOWN (0x52345362)':
-					// 0x52345362 is the superblock for Reiser4
-					$fs = 'Reiser4';
-					break;
-				case 'UNKNOWN (0x565a4653)':
-					// 0x52345362 is the superblock for ResierFS
-					$fs = 'ReiserFS';
-					break;
-				case 'UNKNOWN (0x3434)':
-					// 0x3434 is the superblock for NILFS2
-					$fs = 'NILFS2';
-					break;
-				case 'UNKNOWN (0x24051905)':
-					// 0x24051905 is the superblock for UBIFS
-					$fs = 'UBIFS';
-					break;
-				case 'UNKNOWN (0x65735546)':
-					// 0x65735546 is the superblock for the FUSE module
-					$fs = 'FUSE';
-					break;
-				case 'UNKNOWN (0x5346414f)':
-					// 0x65735546 is the superblock for OpenAFS
-					$fs = 'OpenAFS';
-					break;
-				case 'UNKNOWN (0xff534d42)':
-					// 0x65735546 is the superblock for CIFS
-					$fs = 'CIFS';
-					break;
-				case 'UNKNOWN (0x65735546)':
-					// 0x65735546 is the superblock for SSHFS
-					$fs = 'SSHFS';
-					break;
-				case 'UNKNOWN (0x5941ff53)':
-					// 0x5941ff53 is the superblock for SSHFS
-					$fs = 'YAFFS';
-					break;
 				case 'Case-sensitive Journaled HFS+':
-				case 'UNKNOWN (0x482b)':
-					// 0x482b is the superblock for HFS+
 					$fs = 'HFS+';
 					break;
-				case 'UNKNOWN (0x2fc12fc1)':
-					// 0x2fc12fc1 is KQ Infotech ZFS
-					$fs = 'zfs';
+				case 'MS-DOS FAT32':
+					$fs = 'FAT32';
 					break;
-				case 'UNKNOWN (0x47504653)':
-					// 0x47504653 is GPFS
-					$fs = 'GPFS';
+				case 'UFSD_NTFS_COMPR':
+					$fs = 'NTFS';
+					break;
+				default:
+					if(substr($fs, 0, 9) == 'UNKNOWN (')
+					{
+						$magic_block = substr($fs, 9, -1);
+						$known_magic_blocks = array(
+							'0x9123683e' => 'Btrfs',
+							'0x2fc12fc1' => 'zfs', // KQ Infotech ZFS
+							'0x482b' => 'HFS+',
+							'0x65735546' => 'FUSE',
+							'0x565a4653' => 'ReiserFS',
+							'0x52345362' => 'Reiser4',
+							'0x3434' => 'NILFS2',
+							'0x5346414f' => 'OpenAFS',
+							'0x47504653' => 'GPFS',
+							'0x5941ff53' => 'YAFFS',
+							'0x65735546' => 'SSHFS',
+							'0xff534d42' => 'CIFS',
+							'0x24051905' => 'UBIFS',
+							'0x1021994' => 'TMPFS',
+							'0x73717368' => 'SquashFS',
+							'0xc97e8168' => 'LogFS',
+							'0x65735546' => 'SSHFS',
+							'0x5346544E' => 'NTFS'
+							);
+
+						foreach($known_magic_blocks as $hex => $name)
+						{
+							if($magic_block == $hex)
+							{
+								$fs = $name;
+								break;
+							}
+						}
+					}
 					break;
 			}
 
@@ -282,18 +297,18 @@ class phodevi_system extends phodevi_device_interface
 				$mounts = file_get_contents('/proc/mounts');
 				$fs_r = array();
 
-				if(strpos($mounts, 'squashfs') != false)
-				{
-					array_push($fs_r, 'SquashFS');
-				}
+				$fs_checks = array(
+					'squashfs' => 'SquashFS',
+					'aufs' => 'AuFS',
+					'unionfs' => 'UnionFS'
+					);
 
-				if(strpos($mounts, 'aufs') != false)
+				foreach($fs_checks as $fs_module => $fs_name)
 				{
-					array_push($fs_r, 'AuFS');
-				}
-				else if(strpos($mounts, 'unionfs') != false)
-				{
-					array_push($fs_r, 'UnionFS');
+					if(strpos($mounts, $fs_module) != false)
+					{
+						array_push($fs_r, $fs_name);
+					}
 				}
 
 				if(count($fs_r) > 0)
@@ -324,7 +339,7 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$virtualized = 'QEMU';
 		}
-		else if(strpos($gpu, 'VMware') !== false)
+		else if(strpos($gpu, 'VMware') !== false || (is_readable('/sys/class/dmi/id/product_name') && stripos(pts_file_io::file_get_contents('/sys/class/dmi/id/product_name'), 'VMware') !== false))
 		{
 			$virtualized = 'VMware';
 		}
@@ -333,11 +348,6 @@ class phodevi_system extends phodevi_device_interface
 			$virtualized = 'VirtualBox';
 		}
 
-		if($virtualized != null)
-		{
-			$virtualized = 'This system was using ' . $virtualized . ' virtualization';
-		}
-
 		return $virtualized;
 	}
 	public static function sw_compiler()
@@ -474,6 +484,7 @@ class phodevi_system extends phodevi_device_interface
 					break;
 				case 'i86pc':
 				case 'i586':
+				case 'i686-AT386':
 					$kernel_arch = 'i686';
 					break;
 			}
@@ -509,7 +520,19 @@ class phodevi_system extends phodevi_device_interface
 	public static function sw_operating_system()
 	{
 		// Determine the operating system release
-		$vendor = phodevi::is_linux() ? phodevi_linux_parser::read_lsb_distributor_id() : false;
+		if(phodevi::is_linux())
+		{
+			$vendor = phodevi_linux_parser::read_lsb_distributor_id();
+		}
+		else if(phodevi::is_hurd())
+		{
+			$vendor = php_uname('v');
+		}
+		else
+		{
+			$vendor = null;
+		}
+
 		$version = phodevi::read_property('system', 'os-version');
 
 		if(!$vendor)
