@@ -25,6 +25,10 @@
 //if(PTS_IS_CLIENT || (defined('PTS_LIB_GRAPH_CONFIG_XML') && is_file(PTS_LIB_GRAPH_CONFIG_XML)))
 pts_Graph::$graph_config = new pts_graph_config_nye_XmlReader();
 
+
+// TODO: performance optimizations...
+// OpenBenchmarking.org 1107247-LI-MESACOMMI48 is a good large data set test to render to look for speed differences
+
 abstract class pts_Graph
 {
 	// Graph config
@@ -80,7 +84,7 @@ abstract class pts_Graph
 	protected $graph_maximum_value;
 
 	protected $graph_output = null;
-	protected $graph_renderer;
+	protected $graph_renderer = 'SVG';
 	protected $graph_data = array();
 	protected $graph_data_raw = array();
 	protected $graph_data_title = array();
@@ -106,7 +110,7 @@ abstract class pts_Graph
 	protected $is_multi_way_comparison = false;
 	private $test_identifier = null;
 	protected $iveland_view = false;
-	protected $link_alternate_table = null;
+	protected $link_alternate_view = null;
 	protected $value_highlights = array();
 
 	public function __construct(&$result_object = null, &$result_file = null)
@@ -205,7 +209,10 @@ abstract class pts_Graph
 	}
 	public function requestRenderer($renderer)
 	{
-		$this->graph_renderer = $renderer;
+		if($renderer != null)
+		{
+			$this->graph_renderer = $renderer;
+		}
 	}
 	public function getRenderer()
 	{
@@ -286,11 +293,11 @@ abstract class pts_Graph
 	{
 		$this->graph_output = $file;
 	}
-	public function htmlEmbedCode($file, $width, $height)
+	public function htmlEmbedCode($file, $width = null, $height = null)
 	{
 		$attributes = array();
 
-		if(in_array($this->graph_renderer, array('SWF', 'SVG')))
+		if(in_array($this->graph_renderer, array('SWF', 'SVG')) && $width != null)
 		{
 			$attributes['width'] = $width;
 			$attributes['height'] = $height;
@@ -315,10 +322,6 @@ abstract class pts_Graph
 	// Misc Functions
 	//
 
-	protected function next_paint_color()
-	{
-		return get_paint_color(time());
-	}
 	protected function get_paint_color($identifier)
 	{
 		return $this->graph_image->convert_hex_to_type(bilde_renderer::color_cache(0, $identifier, $this->graph_color_paint));
@@ -363,12 +366,12 @@ abstract class pts_Graph
 	}
 	protected function text_size_bounds($string, $font, $font_size, $minimum_font_size, $bound_width, $bound_height = -1)
 	{
-		list($string_width, $string_height) = $this->text_string_dimensions($string, $font, $font_size);
+		list($string_width, $string_height) = bilde_renderer::soft_text_string_dimensions($string, $font, $font_size);
 
 		while($font_size > $minimum_font_size && $string_width > $bound_width || ($bound_height > 0 && $string_height > $bound_height))
 		{
 			$font_size -= 0.2;
-			list($string_width, $string_height) = $this->text_string_dimensions($string, $font, $font_size);
+			list($string_width, $string_height) = bilde_renderer::soft_text_string_dimensions($string, $font, $font_size);
 		}
 
 		return $font_size;
@@ -377,32 +380,6 @@ abstract class pts_Graph
 	{
 		$this->value_highlights = $values;
 	}
-	protected function find_longest_string(&$string_r)
-	{
-		$longest_string = null;
-		$longest_string_length = 0;
-
-		if(!is_array($string_r))
-		{
-			$string_r = array($string_r);
-		}
-
-		foreach($string_r as $one_string)
-		{
-			if(is_array($one_string))
-			{
-				$one_string = $this->find_longest_string($one_string);
-			}
-
-			if(($new_length = strlen($one_string)) > $longest_string_length)
-			{
-				$longest_string = $one_string;
-				$longest_string_length = $new_length;
-			}
-		}
-
-		return $longest_string;
-	}
 	protected function update_graph_dimensions($width = -1, $height = -1, $recalculate_offsets = false)
 	{
 		// Allow render area to be increased, but not decreased
@@ -458,7 +435,7 @@ abstract class pts_Graph
 				if($this->is_multi_way_comparison && count($this->graph_data_title) > 1)
 				{
 					// TODO: verify this is good and covered for all scenarios
-					$longest_r = $this->find_longest_string($this->graph_identifiers);
+					$longest_r = pts_strings::find_longest_string($this->graph_identifiers);
 					$longest_r = explode(' - ', $longest_r);
 					$plus_extra = 0;
 
@@ -471,7 +448,7 @@ abstract class pts_Graph
 				}
 				else
 				{
-					$longest_identifier_width = $this->text_string_width($this->find_longest_string($this->graph_identifiers), $this->graph_font, $this->graph_font_size_identifiers) + 8;
+					$longest_identifier_width = $this->text_string_width(pts_strings::find_longest_string($this->graph_identifiers), $this->graph_font, $this->graph_font_size_identifiers) + 8;
 				}
 
 				$longest_identifier_max = $this->graph_attr_width * 0.5;
@@ -504,8 +481,8 @@ abstract class pts_Graph
 			{
 				if($this->is_multi_way_comparison && count($this->graph_data) > 1)
 				{
-					$longest_string = $this->find_longest_string($this->graph_identifiers);
-					$longest_string = $this->find_longest_string(explode(' - ', $longest_string));
+					$longest_string = explode(' - ', pts_strings::find_longest_string($this->graph_identifiers));
+					$longest_string = pts_strings::find_longest_string($longest_string);
 
 					$rotated_text = round($this->text_string_width($longest_string, $this->graph_font, $this->graph_font_size_identifiers) * 0.96);
 					$per_identifier_height = max((14 + (22 * count($this->graph_data))), $rotated_text);
@@ -544,9 +521,14 @@ abstract class pts_Graph
 		$this->render_graph_pre_init();
 		$this->render_graph_init();
 	}
-	public function setAlternateLocation($location)
+	public function setAlternateLocation($url)
 	{
-		$this->link_alternate_table = $location;
+		// this has been replaced by setAlternateView
+		return false;
+	}
+	public function setAlternateView($url)
+	{
+		$this->link_alternate_view = $url;
 	}
 	public function render_graph_finish()
 	{
@@ -659,13 +641,13 @@ abstract class pts_Graph
 	{
 		if($this->iveland_view)
 		{
-			$bottom_heading_start = $this->graph_top_end + $this->graph_bottom_offset + 25;
+			$bottom_heading_start = $this->graph_top_end + $this->graph_bottom_offset + 22;
 			$this->graph_image->draw_rectangle(0, $bottom_heading_start, $this->graph_attr_width, $this->graph_attr_height, $this->graph_color_main_headers);
-			$this->graph_image->write_text_right(new pts_graph_ir_value('Powered By ' . $this->graph_version, array('href' => 'http://www.phoronix-test-suite.com/')), $this->graph_font, 7, $this->graph_color_background, $this->graph_left_end, $bottom_heading_start + 7, $this->graph_left_end, $bottom_heading_start + 7);
+			$this->graph_image->write_text_right(new pts_graph_ir_value('Powered By ' . $this->graph_version, array('href' => 'http://www.phoronix-test-suite.com/')), $this->graph_font, 7, $this->graph_color_background, $this->graph_left_end, $bottom_heading_start + 9, $this->graph_left_end, $bottom_heading_start + 9);
 
-			if($this->link_alternate_table != null)
+			if($this->link_alternate_view != null)
 			{
-				$this->graph_image->write_text_left(new pts_graph_ir_value('T', array('href' => $this->link_alternate_table, 'show' => 'replace', 'font-weight' => 'bold')), $this->graph_font, 7, $this->graph_color_background, 6, $bottom_heading_start + 7, 6, $bottom_heading_start + 7);
+				$this->graph_image->image_copy_merge(new pts_graph_ir_value($this->graph_image->png_image_to_type('http://openbenchmarking.org/ob-10x16.png'), array('href' => $this->link_alternate_view)), 4, $bottom_heading_start + 1, 0, 0, 10, 16);
 			}
 		}
 	}
@@ -708,7 +690,7 @@ abstract class pts_Graph
 				switch($this->graph_proportion)
 				{
 					case 'LIB':
-						$proportion = 'Less Are Better';
+						$proportion = 'Less Is Better';
 						$offset += 12;
 
 						if($this->graph_orientation == 'HORIZONTAL')
@@ -721,7 +703,7 @@ abstract class pts_Graph
 						}
 						break;
 					case 'HIB':
-						$proportion = 'More Are Better';
+						$proportion = 'More Is Better';
 						$offset += 12;
 						if($this->graph_orientation == 'HORIZONTAL')
 						{
@@ -820,7 +802,7 @@ abstract class pts_Graph
 		}
 
 		$this->graph_key_line_height = 16;
-		$this->graph_key_item_width = 16 + $this->text_string_width($this->find_longest_string($this->graph_data_title), $this->graph_font, $this->graph_font_size_key);
+		$this->graph_key_item_width = 16 + $this->text_string_width(pts_strings::find_longest_string($this->graph_data_title), $this->graph_font, $this->graph_font_size_key);
 		$this->graph_keys_per_line = floor(($this->graph_left_end - $this->graph_left_start) / $this->graph_key_item_width);
 
 		return ceil(count($this->graph_data_title) / $this->graph_keys_per_line) * $this->graph_key_line_height;
@@ -880,18 +862,14 @@ abstract class pts_Graph
 	// Renderer-specific Functions
 	//
 
-	protected function text_string_dimensions($string, $font, $size, $big = false)
-	{
-		return bilde_renderer::soft_text_string_dimensions($string, $font, $size, $big);
-	}
 	protected function text_string_width($string, $font, $size)
 	{
-		$dimensions = $this->text_string_dimensions($string, $font, $size);
+		$dimensions = bilde_renderer::soft_text_string_dimensions($string, $font, $size);
 		return $dimensions[0];
 	}
 	protected function text_string_height($string, $font, $size)
 	{
-		$dimensions = $this->text_string_dimensions($string, $font, $size);
+		$dimensions = bilde_renderer::soft_text_string_dimensions($string, $font, $size);
 		return $dimensions[1];
 	}
 }
