@@ -42,12 +42,12 @@ class pts_LineGraph extends pts_Graph
 		$identifier_count = $graph_identifiers_count > 1 ? $graph_identifiers_count : count($this->graph_data[0]);
 		$this->identifier_width = ($this->graph_left_end - $this->graph_left_start) / ($identifier_count + 1);
 
-		$longest_string = $this->find_longest_string($this->graph_identifiers);
+		$longest_string = pts_strings::find_longest_string($this->graph_identifiers);
 		$this->graph_font_size_identifiers = $this->text_size_bounds($longest_string, $this->graph_font, $this->graph_font_size_identifiers, $this->minimum_identifier_font, $this->identifier_width - 4);
 
 		if($this->graph_font_size_identifiers <= $this->minimum_identifier_font)
 		{
-			list($text_width, $text_height) = $this->text_string_dimensions($longest_string, $this->graph_font, $this->minimum_identifier_font + 0.5);
+			list($text_width, $text_height) = bilde_renderer::soft_text_string_dimensions($longest_string, $this->graph_font, $this->minimum_identifier_font + 0.5);
 			$this->graph_bottom_offset += $text_width;
 			$this->update_graph_dimensions($this->graph_attr_width, $this->graph_attr_height + $text_width);
 
@@ -67,7 +67,14 @@ class pts_LineGraph extends pts_Graph
 			return;
 		}
 
-		$this->graph_image->draw_dashed_line($this->graph_left_start + $this->identifier_width, $this->graph_top_end, $this->graph_left_end, $this->graph_top_end, $this->graph_color_notches, 10, 1, $this->identifier_width - 1);
+		if($this->identifier_width > 2)
+		{
+			$this->graph_image->draw_dashed_line($this->graph_left_start + $this->identifier_width, $this->graph_top_end, $this->graph_left_end, $this->graph_top_end, $this->graph_color_notches, 10, 1, $this->identifier_width - 1);
+		}
+		else if($this->show_select_identifiers != null)
+		{
+			$this->graph_image->draw_dashed_line($this->graph_left_start + ($this->identifier_width * $this->show_select_identifiers), $this->graph_top_end, $this->graph_left_end, $this->graph_top_end, $this->graph_color_notches, 10, 1, ($this->identifier_width * $this->show_select_identifiers) - 1);
+		}
 
 		foreach(array_keys($this->graph_identifiers) as $i)
 		{
