@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2010, Phoronix Media
-	Copyright (C) 2009 - 2010, Michael Larabel
+	Copyright (C) 2009 - 2011, Phoronix Media
+	Copyright (C) 2009 - 2011, Michael Larabel
 	pts_Table.php: A charting table object for pts_Graph
 
 	This program is free software; you can redistribute it and/or modify
@@ -60,8 +60,8 @@ class pts_Table extends pts_Graph
 		$this->table_data = $table_data;
 
 		// Do some calculations
-		$this->longest_column_identifier = $this->find_longest_string($this->columns);
-		$this->longest_row_identifier = $this->find_longest_string($this->rows);
+		$this->longest_column_identifier = pts_strings::find_longest_string($this->columns);
+		$this->longest_row_identifier = pts_strings::find_longest_string($this->rows);
 		$this->graph_maximum_value = $this->find_longest_string_in_table_data($this->table_data);
 
 		foreach($this->columns as &$column)
@@ -98,10 +98,10 @@ class pts_Table extends pts_Graph
 					$value = $row;
 				}
 
-				if(($new_length = strlen($value)) > $longest_string_length)
+				if(isset($value[$longest_string_length]))
 				{
 					$longest_string = $value;
-					$longest_string_length = $new_length;
+					$longest_string_length = strlen($value);
 				}
 			}
 		}
@@ -203,9 +203,9 @@ class pts_Table extends pts_Graph
 			$this->graph_image->write_text_left(new pts_graph_ir_value($this->graph_version, array('href' => 'http://www.phoronix-test-suite.com/')), $this->graph_font, $this->graph_font_size_identifiers, $this->graph_color_body_text, 2, $table_proper_height + $table_line_height_half, 2, $table_proper_height + $table_line_height_half);
 		}
 		*/
-		if($this->link_alternate_table != null)
+		if($this->link_alternate_view != null)
 		{
-			$this->graph_image->write_text_left(new pts_graph_ir_value('G', array('href' => $this->link_alternate_table, 'show' => 'replace', 'font-weight' => 'bold')), $this->graph_font, 7, $this->graph_color_background, 6, $table_proper_height + $table_line_height_half, 6, $table_proper_height + $table_line_height_half);
+			$this->graph_image->write_text_left(new pts_graph_ir_value('O', array('href' => $this->link_alternate_view, 'show' => 'replace', 'font-weight' => 'bold')), $this->graph_font, 7, $this->graph_color_background, 6, $table_proper_height + $table_line_height_half, 6, $table_proper_height + $table_line_height_half);
 		}
 
 		// Heading
