@@ -48,6 +48,11 @@ class pts_client
 		self::basic_init_process(); // Initalize common / needed PTS start-up work
 		self::core_storage_init_process();
 
+		if(!is_file(PTS_TEMP_STORAGE))
+		{
+			self::build_temp_cache();
+		}
+
 		pts_config::init_files();
 		define('PTS_TEST_INSTALL_DEFAULT_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Installation/EnvironmentDirectory', '~/.phoronix-test-suite/installed-tests/')));
 		define('PTS_SAVE_RESULTS_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Testing/ResultsDirectory', '~/.phoronix-test-suite/test-results/')));
@@ -65,7 +70,6 @@ class pts_client
 	public static function module_framework_init()
 	{
 		// Process initially called when PTS starts up
-
 		// Check for modules to auto-load from the configuration file
 		$load_modules = pts_config::read_user_config('PhoronixTestSuite/Options/Modules/LoadModules', null);
 
@@ -142,6 +146,31 @@ class pts_client
 		define('PTS_STARTUP_TASK_PERFORMED', true);
 		register_shutdown_function(array('pts_module_manager', 'module_process'), '__shutdown');
 	}
+	public static function open_basedir_check()
+	{
+		$passes = true;
+		$open_basedir = ini_get('open_basedir');
+
+		if($open_basedir != false)
+		{
+			$is_in_allowed_dir = false;
+			foreach(explode(':', $open_basedir) as $allowed_dir)
+			{
+				if(strpos(PTS_PATH, $allowed_dir) === 0)
+				{
+					$is_in_allowed_dir = true;
+					break;
+				}
+			}
+
+			if($is_in_allowed_dir == false)
+			{
+				$passes = false;
+			}
+		}
+
+		return $passes;
+	}
 	public static function environmental_variables()
 	{
 		// The PTS environmental variables passed during the testing process, etc
@@ -213,6 +242,96 @@ class pts_client
 
 		return $runtime_variables;
 	}
+	public static function save_test_result($save_to = null, $save_results = null, $render_graphs = true, $result_identifier = null)
+	{
+		// Saves PTS result file
+		if(substr($save_to, -4) != '.xml')
+		{
+			$save_to .= '.xml';
+		}
+
+		$save_to_dir = pts_client::setup_test_result_directory($save_to);
+
+		if($save_to == null || $save_results == null)
+		{
+			$bool = false;
+		}
+		else
+		{
+			$save_name = basename($save_to, '.xml');
+
+			if($save_name == 'composite' && $render_graphs)
+			{
+				pts_client::generate_result_file_graphs($save_results, $save_to_dir);
+			}
+
+			$bool = file_put_contents(PTS_SAVE_RESULTS_PATH . $save_to, $save_results);
+
+			if($result_identifier != null && (pts_config::read_bool_config('PhoronixTestSuite/Options/Testing/SaveSystemLogs', 'TRUE') || (pts_c::$test_flags & pts_c::batch_mode) || (pts_c::$test_flags & pts_c::auto_mode)))
+			{
+				// Save verbose system information here
+				$system_log_dir = $save_to_dir . '/system-logs/' . $result_identifier . '/';
+				pts_file_io::mkdir($system_log_dir, 0777, true);
+
+				// Backup system files
+				// TODO: move out these files/commands to log out to respective Phodevi components so only what's relevant will be logged
+				$system_log_files = array(
+					'/var/log/Xorg.0.log',
+					'/proc/cpuinfo',
+					'/proc/modules',
+					'/proc/mounts',
+					'/proc/cmdline',
+					'/etc/X11/xorg.conf'
+					);
+
+				/*
+				if(phodevi::is_linux())
+				{
+					// the kernel config file might just be too large to upload for now
+					array_push($system_log_files, '/boot/config-' . php_uname('r'));
+				}
+				*/
+
+				foreach($system_log_files as $file)
+				{
+					if(is_file($file) && is_readable($file))
+					{
+						// copy() can't be used in this case since it will result in a blank file for /proc/ file-system
+						file_put_contents($system_log_dir . basename($file), file_get_contents($file));
+					}
+				}
+
+				// Generate logs from system commands to backup
+				$system_log_commands = array(
+					'lspci -vvnn',
+					'cc -v',
+					'lsusb',
+					'lsmod',
+					'sensors',
+					'dmesg',
+					'glxinfo'
+					);
+
+				if(phodevi::is_bsd())
+				{
+					array_push($system_log_commands, 'sysctl -a');
+				}
+
+				foreach($system_log_commands as $command_string)
+				{
+					$command = explode(' ', $command_string);
+
+					if(($command_bin = pts_client::executable_in_path($command[0])))
+					{
+						$cmd_output = shell_exec('cd ' . dirname($command_bin) . ' && ./' . $command_string . ' 2>&1');
+						file_put_contents($system_log_dir . $command[0], $cmd_output);
+					}
+				}
+			}
+		}
+
+		return $bool;
+	}
 	public static function save_result_file(&$result_file_writer, $save_name)
 	{
 		// Save the test file
@@ -267,14 +386,7 @@ class pts_client
 	}
 	public static function init_display_mode($flags = 0)
 	{
-		if(($flags & pts_c::debug_mode))
-		{
-			$env_mode = 'BASIC';
-		}
-		else
-		{
-			$env_mode = false;
-		}
+		$env_mode = ($flags & pts_c::debug_mode) ? 'BASIC' : false;
 
 		switch(($env_mode != false || ($env_mode = pts_client::read_env('PTS_DISPLAY_MODE')) != false ? $env_mode : pts_config::read_user_config('PhoronixTestSuite/Options/General/DefaultDisplayMode', 'DEFAULT')))
 		{
@@ -294,7 +406,18 @@ class pts_client
 	private static function extended_init_process()
 	{
 		// Extended Initalization Process
-		$directory_check = array(PTS_TEST_INSTALL_DEFAULT_PATH, PTS_SAVE_RESULTS_PATH, PTS_MODULE_LOCAL_PATH, PTS_MODULE_DATA_PATH, PTS_DOWNLOAD_CACHE_PATH, PTS_OPENBENCHMARKING_SCRATCH_PATH, PTS_TEST_PROFILE_PATH, PTS_TEST_SUITE_PATH, PTS_TEST_PROFILE_PATH . 'local/', PTS_TEST_SUITE_PATH . 'local/');
+		$directory_check = array(
+			PTS_TEST_INSTALL_DEFAULT_PATH,
+			PTS_SAVE_RESULTS_PATH,
+			PTS_MODULE_LOCAL_PATH,
+			PTS_MODULE_DATA_PATH,
+			PTS_DOWNLOAD_CACHE_PATH,
+			PTS_OPENBENCHMARKING_SCRATCH_PATH,
+			PTS_TEST_PROFILE_PATH,
+			PTS_TEST_SUITE_PATH,
+			PTS_TEST_PROFILE_PATH . 'local/',
+			PTS_TEST_SUITE_PATH . 'local/'
+			);
 
 		foreach($directory_check as $dir)
 		{
@@ -350,7 +473,7 @@ class pts_client
 					// This extension is missing but optional
 					if($printed_optional_header == false)
 					{
-						echo PHP_EOL . 'The following PHP extensions are optional but recommended by the Phoronix Test Suite:' . PHP_EOL . PHP_EOL;
+						echo PHP_EOL . ($printed_required_header ? null : 'NOTICE: ') . 'The following PHP extensions are OPTIONAL but recommended:' . PHP_EOL . PHP_EOL;
 						$printed_optional_header = true;
 					}
 				}
@@ -359,12 +482,31 @@ class pts_client
 			}
 		}
 
-		if($printed_required_header)
+		if($printed_required_header || $printed_optional_header)
 		{
 			echo PHP_EOL;
-			exit;
+
+			if($printed_required_header)
+			{
+				exit;
+			}
 		}
 	}
+	private static function build_temp_cache()
+	{
+		$pso = pts_storage_object::recover_from_file(PTS_TEMP_STORAGE);
+
+		if($pso == false)
+		{
+			$pso = new pts_storage_object();
+		}
+
+		$pso->add_object('environmental_variables_for_modules', pts_module_manager::modules_environmental_variables());
+		$pso->add_object('vendor_alias_list', pts_external_dependencies::vendor_alias_list());
+		$pso->add_object('command_alias_list', pts_documentation::client_commands_aliases());
+
+		$pso->save_to_file(PTS_TEMP_STORAGE);
+	}
 	private static function core_storage_init_process()
 	{
 		$pso = pts_storage_object::recover_from_file(PTS_CORE_STORAGE);
@@ -416,7 +558,9 @@ class pts_client
 
 		// Last Run Processing
 		$last_core_version = $pso->read_object('last_core_version');
-		if($last_core_version != PTS_CORE_VERSION)
+		define('FIRST_RUN_ON_PTS_UPGRADE', ($last_core_version != PTS_CORE_VERSION));
+
+		if(FIRST_RUN_ON_PTS_UPGRADE)
 		{
 			// Report any missing/recommended extensions
 			self::program_requirement_checks();
@@ -425,6 +569,8 @@ class pts_client
 			{
 				pts_openbenchmarking_client::update_gsid();
 			}
+
+			pts_client::build_temp_cache();
 		}
 		$pso->add_object('last_core_version', PTS_CORE_VERSION); // PTS version last run
 
@@ -702,6 +848,16 @@ class pts_client
 		}
 
 		$raw_xsl = file_get_contents(PTS_RESULTS_VIEWER_PATH . 'pts-results-viewer.xsl');
+
+		// System Tables
+		$conversions = array('systems', 'radar', 'overview', 'visualize');
+		foreach($conversions as $convert)
+		{
+			$graph_string = pts_render::$last_graph_object->htmlEmbedCode('result-graphs/' . $convert . '.BILDE_EXTENSION');
+			$raw_xsl = str_replace('<!-- ' . strtoupper($convert) . ' TAG -->', $graph_string, $raw_xsl);
+		}
+
+		// Result Graphs
 		$graph_string = pts_render::$last_graph_object->htmlEmbedCode('result-graphs/<xsl:number value="position()" />.BILDE_EXTENSION', $width, $height);
 
 		$raw_xsl = str_replace('<!-- GRAPH TAG -->', $graph_string, $raw_xsl);
@@ -742,7 +898,15 @@ class pts_client
 			$chart = new pts_ResultFileTable($result_file);
 			$chart->renderChart($save_to_dir . '/result-graphs/overview.BILDE_EXTENSION');
 
-			$chart = new pts_ResultFileSystemsTable($result_file);
+			$intent = -1;
+			if($result_file->get_system_count() == 1 || ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)))
+			{
+				$chart = new pts_ResultFileCompactSystemsTable($result_file, $intent);
+			}
+			else
+			{
+				$chart = new pts_ResultFileSystemsTable($result_file);
+			}
 			$chart->renderChart($save_to_dir . '/result-graphs/systems.BILDE_EXTENSION');
 			unset($chart);
 		}
@@ -776,14 +940,13 @@ class pts_client
 					}
 
 					$chart = new pts_ResultFileTable($result_file, null, $table_keys);
-					$chart->setAlternateLocation($save_to_dir . '/result-graphs/' . ($key + 1) . '.svg');
 					$chart->renderChart($save_to_dir . '/result-graphs/' . ($key + 1) . '_table.BILDE_EXTENSION');
 					unset($chart);
 					$generated_graph_tables = true;
 				}
 			}
 
-			$graph = pts_render::render_graph($result_object, $result_file, $save_to, array('set_alternate_location' => $save_to_dir . '/result-graphs/' . ($key + 1) . '_table.svg'));
+			$graph = pts_render::render_graph($result_object, $result_file, $save_to);
 			array_push($generated_graphs, $graph);
 		}
 
@@ -804,6 +967,21 @@ class pts_client
 				}
 			}
 			unset($graph);
+
+			$graph = new pts_RadarOverviewGraph($result_file);
+
+			if($graph->doSkipGraph() == false)
+			{
+				$graph->saveGraphToFile($save_to_dir . '/result-graphs/radar.BILDE_EXTENSION');
+				$graph->renderGraph();
+
+				// Check to see if skip_graph was realized during the rendering process
+				if($graph->doSkipGraph() == true)
+				{
+					pts_file_io::unlink($save_to_dir . '/result-graphs/radar.svg');
+				}
+			}
+			unset($graph);
 		}
 
 		// Save XSL
@@ -878,96 +1056,6 @@ class pts_client
 
 		return $in_option;
 	}
-	public static function save_test_result($save_to = null, $save_results = null, $render_graphs = true, $result_identifier = null)
-	{
-		// Saves PTS result file
-		if(substr($save_to, -4) != '.xml')
-		{
-			$save_to .= '.xml';
-		}
-
-		$save_to_dir = pts_client::setup_test_result_directory($save_to);
-	
-		if($save_to == null || $save_results == null)
-		{
-			$bool = false;
-		}
-		else
-		{
-			$save_name = basename($save_to, '.xml');
-
-			if($save_name == 'composite' && $render_graphs)
-			{
-				pts_client::generate_result_file_graphs($save_results, $save_to_dir);
-			}
-
-			$bool = file_put_contents(PTS_SAVE_RESULTS_PATH . $save_to, $save_results);
-
-			if($result_identifier != null && (pts_config::read_bool_config('PhoronixTestSuite/Options/Testing/SaveSystemLogs', 'TRUE') || (pts_c::$test_flags & pts_c::batch_mode) || (pts_c::$test_flags & pts_c::auto_mode)))
-			{
-				// Save verbose system information here
-				$system_log_dir = $save_to_dir . '/system-logs/' . $result_identifier . '/';
-				pts_file_io::mkdir($system_log_dir, 0777, true);
-
-				// Backup system files
-				// TODO: move out these files/commands to log out to respective Phodevi components so only what's relevant will be logged
-				$system_log_files = array(
-					'/var/log/Xorg.0.log',
-					'/proc/cpuinfo',
-					'/proc/modules',
-					'/proc/mounts',
-					'/proc/cmdline',
-					'/etc/X11/xorg.conf'
-					);
-
-				/*
-				if(phodevi::is_linux())
-				{
-					// the kernel config file might just be too large to upload for now
-					array_push($system_log_files, '/boot/config-' . php_uname('r'));
-				}
-				*/
-
-				foreach($system_log_files as $file)
-				{
-					if(is_file($file) && is_readable($file))
-					{
-						// copy() can't be used in this case since it will result in a blank file for /proc/ file-system
-						file_put_contents($system_log_dir . basename($file), file_get_contents($file));
-					}
-				}
-
-				// Generate logs from system commands to backup
-				$system_log_commands = array(
-					'lspci -vvnn',
-					'cc -v',
-					'lsusb',
-					'lsmod',
-					'sensors',
-					'dmesg',
-					'glxinfo'
-					);
-
-				if(phodevi::is_bsd())
-				{
-					array_push($system_log_commands, 'sysctl -a');
-				}
-
-				foreach($system_log_commands as $command_string)
-				{
-					$command = explode(' ', $command_string);
-
-					if(($command_bin = pts_client::executable_in_path($command[0])))
-					{
-						$cmd_output = shell_exec('cd ' . dirname($command_bin) . ' && ./' . $command_string . ' 2>&1');
-						file_put_contents($system_log_dir . $command[0], $cmd_output);
-					}
-				}
-			}
-		}
-
-		return $bool;
-	}
 	public static function regenerate_graphs($result_file_identifier, $full_process_string = false, $extra_graph_attributes = null)
 	{
 		$save_to_dir = pts_client::setup_test_result_directory($result_file_identifier);
@@ -1083,10 +1171,9 @@ class pts_client
 				echo PHP_EOL . 'There is an error in the requested command: ' . $command . PHP_EOL . PHP_EOL;
 			}
 		}
-		else if(pts_module::valid_run_command($command))
+		else if(($t = pts_module::valid_run_command($command)) != false)
 		{
-			list($module, $module_command) = explode('.', $command);
-
+			list($module, $module_command) = $t;
 			pts_module_manager::set_current_module($module);
 			pts_module_manager::run_command($module, $module_command, $pass_args);
 			pts_module_manager::set_current_module(null);
@@ -1094,21 +1181,6 @@ class pts_client
 
 		pts_module_manager::module_process('__post_option_process', $command);
 	}
-	public static function read_openbenchmarking_dom(&$dom, $id, $fallback = false)
-	{
-		$tag = $dom->getElementById($id);
-
-		if($tag instanceof DOMElement && $tag->tagName == 'input')
-		{
-			$value = $tag->getAttribute('value');
-		}
-		else
-		{
-			$value = $fallback;
-		}
-
-		return $value;
-	}
 	public static function terminal_width()
 	{
 		static $terminal_width = null;
@@ -1409,13 +1481,7 @@ class pts_client
 				}
 				else
 				{
-					$possible_browsers = array('epiphany', 'firefox', 'mozilla', 'x-www-browser', 'open');
-
-					if(pts_client::executable_in_path('kfmclient') == false)
-					{
-						// Konqueror is bad with XSL, so if it looks like we are using KDE, don't use XDG
-						array_unshift($possible_browsers, 'xdg-open');
-					}
+					$possible_browsers = array('epiphany', 'firefox', 'mozilla', 'x-www-browser', 'open', 'xdg-open', 'konqueror');
 
 					foreach($possible_browsers as &$b)
 					{
