@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,13 +24,15 @@ class pts_installed_test
 {
 	private $xml_parser;
 
-	public function __construct($identifier)
+	public function __construct(&$test_profile)
 	{
-		$this->xml_parser = new pts_installed_test_tandem_XmlReader($identifier);
+		$install_path = $test_profile->get_install_dir();
+		$read_xml = is_file($install_path . 'pts-install.xml') ? $install_path . 'pts-install.xml' : null;
+		$this->xml_parser = new nye_XmlReader($read_xml);
 	}
 	public function get_install_date_time()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_INSTALLTIME);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/InstallTime');
 	}
 	public function get_install_date()
 	{
@@ -38,7 +40,7 @@ class pts_installed_test
 	}
 	public function get_last_run_date_time()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_LASTRUNTIME);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/LastRunTime');
 	}
 	public function get_last_run_date()
 	{
@@ -46,27 +48,31 @@ class pts_installed_test
 	}
 	public function get_installed_version()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_VERSION);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/Environment/Version');
 	}
 	public function get_average_run_time()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_AVG_RUNTIME);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/AverageRunTime');
 	}
 	public function get_latest_run_time()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_LATEST_RUNTIME);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/LatestRunTime');
+	}
+	public function get_latest_install_time()
+	{
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/InstallTimeLength');
 	}
 	public function get_run_count()
 	{
-		return ($times_run = $this->xml_parser->getXMLValue(P_INSTALL_TEST_TIMESRUN)) != false ? $times_run : 0;
+		return ($times_run = $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/History/TimesRun')) != false ? $times_run : 0;
 	}
 	public function get_installed_checksum()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_CHECKSUM);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/Environment/CheckSum');
 	}
 	public function get_installed_system_identifier()
 	{
-		return $this->xml_parser->getXMLValue(P_INSTALL_TEST_SYSIDENTIFY);
+		return $this->xml_parser->getXMLValue('PhoronixTestSuite/TestInstallation/Environment/SystemIdentifier');
 	}
 }
 
