@@ -66,7 +66,7 @@ class pts_openbenchmarking_client
 		}
 		else if(is_dir($system_log_dir))
 		{
-			$upload_system_logs = pts_user_io::prompt_bool_input('Would you like to attach the system logs (lspci, dmesg, lsusb, etc) to the test result', false, 'UPLOAD_SYSTEM_LOGS');
+			$upload_system_logs = pts_user_io::prompt_bool_input('Would you like to attach the system logs (lspci, dmesg, lsusb, etc) to the test result', true, 'UPLOAD_SYSTEM_LOGS');
 		}
 
 		$system_logs = null;
@@ -221,13 +221,16 @@ class pts_openbenchmarking_client
 	{
 		if($repos == null)
 		{
-			if(!defined('HAS_REFRESHED_OBO_LIST') && $force_refresh == false)
+			if($force_refresh == false)
 			{
-				define('HAS_REFRESHED_OBO_LIST', true);
-			}
-			else
-			{
-				return true;
+				if(!defined('HAS_REFRESHED_OBO_LIST'))
+				{
+					define('HAS_REFRESHED_OBO_LIST', true);
+				}
+				else
+				{
+					return true;
+				}
 			}
 
 			$repos = self::linked_repositories();
@@ -266,7 +269,7 @@ class pts_openbenchmarking_client
 					}
 				}
 
-				if($generated_time > (time() - (86400 * $index_cache_ttl)) && $force_refresh == false)
+				if($generated_time > (time() - (86400 * $index_cache_ttl)) && $force_refresh == false && (!defined('FIRST_RUN_ON_PTS_UPGRADE') || FIRST_RUN_ON_PTS_UPGRADE == false))
 				{
 					// The index is new enough
 					continue;
@@ -285,7 +288,7 @@ class pts_openbenchmarking_client
 			}
 		}
 	}
-	public static function download_test_profile($qualified_identifier, $hash_check = null)
+	public static function download_test_profile($qualified_identifier)
 	{
 		if(is_file(PTS_TEST_PROFILE_PATH . $qualified_identifier . '/test-definition.xml'))
 		{
@@ -296,6 +299,10 @@ class pts_openbenchmarking_client
 
 		if(!is_file($file))
 		{
+			$hash_json = pts_openbenchmarking::make_openbenchmarking_request('test_hash', array('i' => $qualified_identifier));
+			$hash_json = json_decode($hash_json, true);
+			$hash_check = $hash_json['openbenchmarking']['test']['hash'];  // should also check for ['openbenchmarking']['test']['error'] problems
+
 			$test_profile = pts_openbenchmarking::make_openbenchmarking_request('download_test', array('i' => $qualified_identifier));
 
 			if($test_profile != null && ($hash_check == null || $hash_check == sha1($test_profile)))
@@ -320,7 +327,7 @@ class pts_openbenchmarking_client
 
 		return false;
 	}
-	public static function download_test_suite($qualified_identifier, $hash_check = null)
+	public static function download_test_suite($qualified_identifier)
 	{
 		if(is_file(PTS_TEST_SUITE_PATH . $qualified_identifier . '/suite-definition.xml'))
 		{
@@ -331,6 +338,10 @@ class pts_openbenchmarking_client
 
 		if(!is_file($file))
 		{
+			$hash_json = pts_openbenchmarking::make_openbenchmarking_request('suite_hash', array('i' => $qualified_identifier));
+			$hash_json = json_decode($hash_json, true);
+			$hash_check = $hash_json['openbenchmarking']['suite']['hash'];  // should also check for ['openbenchmarking']['suite']['error'] problems
+
 			$test_suite = pts_openbenchmarking::make_openbenchmarking_request('download_suite', array('i' => $qualified_identifier));
 
 			if($test_suite != null && ($hash_check == null || $hash_check == sha1($test_suite)))
@@ -345,7 +356,7 @@ class pts_openbenchmarking_client
 			}
 		}
 
-		if(!is_file(PTS_TEST_SUITE_PATH . $qualified_identifier . '/suite-definition.xml') && ($hash_check == null || sha1_file($file) == $hash_check))
+		if(!is_file(PTS_TEST_SUITE_PATH . $qualified_identifier . '/suite-definition.xml') && ($hash_check == null || (is_file($file) && sha1_file($file) == $hash_check)))
 		{
 			// extract it
 			pts_file_io::mkdir(PTS_TEST_SUITE_PATH . dirname($qualified_identifier));
@@ -435,7 +446,7 @@ class pts_openbenchmarking_client
 				{
 					if(in_array($version, $repo_index['tests'][$test]['versions']))
 					{
-						pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version, $repo_index['tests'][$test]['package_hash']);
+						pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version);
 						return $repo . '/' . $test . ($bind_version ? '-' . $version : null);
 					}
 				}
@@ -443,7 +454,7 @@ class pts_openbenchmarking_client
 				{
 					// Assume to use the latest version
 					$version = array_shift($repo_index['tests'][$test]['versions']);
-					pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version, $repo_index['tests'][$test]['package_hash']);
+					pts_openbenchmarking_client::download_test_profile($repo . '/' . $test . '-' . $version);
 					return $repo . '/' . $test . ($bind_version ? '-' . $version : null);
 				}
 			}
@@ -456,7 +467,7 @@ class pts_openbenchmarking_client
 				{
 					if(in_array($version, $repo_index['suites'][$test]['versions']))
 					{
-						pts_openbenchmarking_client::download_test_suite($repo . '/' . $test . '-' . $version, $repo_index['suites'][$test]['package_hash']);
+						pts_openbenchmarking_client::download_test_suite($repo . '/' . $test . '-' . $version);
 						return $repo . '/' . $test . ($bind_version ? '-' . $version : null);
 					}
 				}
@@ -464,7 +475,7 @@ class pts_openbenchmarking_client
 				{
 					// Assume to use the latest version
 					$version = array_shift($repo_index['suites'][$test]['versions']);
-					pts_openbenchmarking_client::download_test_suite($repo . '/' . $test . '-' . $version, $repo_index['suites'][$test]['package_hash']);
+					pts_openbenchmarking_client::download_test_suite($repo . '/' . $test . '-' . $version);
 					return $repo . '/' . $test . ($bind_version ? '-' . $version : null);
 				}
 			}
@@ -529,7 +540,7 @@ class pts_openbenchmarking_client
 	}
 	public static function user_name()
 	{
-		return isset(self::$openbenchmarking_account['user_name']) ? self::$openbenchmarking_account['user_name'] : null;
+		return isset(self::$openbenchmarking_account['user_name']) ? self::$openbenchmarking_account['user_name'] : false;
 	}
 	public static function upload_usage_data($task, $data)
 	{
@@ -626,7 +637,14 @@ class pts_openbenchmarking_client
 	}
 	public static function linked_repositories()
 	{
-		return array('local', 'pts');
+		$repos = array('local', 'pts');
+
+		if(self::user_name() != false)
+		{
+			array_push($repos, self::user_name());
+		}
+
+		return $repos;
 	}
 }
 
