@@ -77,20 +77,7 @@ class pts_render
 					header('Content-type: image/svg+xml');
 				}
 
-				/*if(false && isset($_SERVER['HTTP_USER_AGENT']) && strpos($_SERVER['HTTP_USER_AGENT'], 'WebKit/') !== false)
-				{
-					$svg_graph = '<img>' . $svg_graph . '</img>';
-				}
-				else
-				{
-					$svg_graph = '<object width="' . $graph->graphWidth() . '" height="' . $graph->graphHeight() . '">' . $svg_graph . '</object>';
-				}*/
-
 				$graph = $svg_graph;
-
-				//$graph = "<object type=\"image/svg+xml\">" . $svg . "</object>";
-				//$graph = "<embed type=\"image/svg+xml\" width=\"" . $graph->graphWidth() . "\" height=\"" . $graph->graphHeight() . "\">" . $svg . "</embed>";
-				// or in WebKit / Chrome / Safari right now we need to embed in <img> if wanting to use auto width/height
 				break;
 			default:
 				$graph = $graph->render_graph_finish();
@@ -105,24 +92,32 @@ class pts_render
 		{
 			if($result_file->is_multi_way_comparison() && in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
 			{
-				// Turn a multi-way line graph into an averaged bar graph
-				$buffer_items = $result_object->test_result_buffer->get_buffer_items();
-				$result_object->test_result_buffer = new pts_test_result_buffer();
-
-				foreach($buffer_items as $buffer_item)
+				// Convert multi-way line graph into horizontal box plot
+				if(false)
 				{
-					$values = pts_strings::comma_explode($buffer_item->get_result_value());
-					$avg_value = pts_math::set_precision(array_sum($values) / count($values), 2);
-					$result_object->test_result_buffer->add_test_result($buffer_item->get_result_identifier(), $avg_value, $avg_value);
+					$result_object->test_profile->set_display_format('HORIZONTAL_BOX_PLOT');
 				}
+				else
+				{
+					// Turn a multi-way line graph into an averaged bar graph
 
-				$result_object->test_profile->set_display_format('BAR_GRAPH');
+					$buffer_items = $result_object->test_result_buffer->get_buffer_items();
+					$result_object->test_result_buffer = new pts_test_result_buffer();
+
+					foreach($buffer_items as $buffer_item)
+					{
+						$values = pts_strings::comma_explode($buffer_item->get_result_value());
+						$avg_value = pts_math::set_precision(array_sum($values) / count($values), 2);
+						$result_object->test_result_buffer->add_test_result($buffer_item->get_result_identifier(), $avg_value);
+					}
+
+					$result_object->test_profile->set_display_format('BAR_GRAPH');
+				}
 			}
 
-			$result_table = false;
-
 			if($result_object->test_profile->get_display_format() != 'PIE_CHART')
 			{
+				$result_table = false;
 				pts_render::compact_result_file_test_object($result_object, $result_table, $result_file->is_multi_way_inverted(), $extra_attributes);
 			}
 		}
@@ -156,7 +151,19 @@ class pts_render
 		switch($display_format)
 		{
 			case 'LINE_GRAPH':
-				$graph = new pts_LineGraph($result_object, $result_file);
+				if(false && $result_object->test_result_buffer->get_count() > 5)
+				{
+					// If there's too many lines close to each other, it's likely to look cluttered so turn it into horizontal range bar / box chart graph
+					$display_format = 'HORIZONTAL_BOX_PLOT';
+					$graph = new pts_HorizontalBoxPlotGraph($result_object, $result_file);
+				}
+				else
+				{
+					$graph = new pts_LineGraph($result_object, $result_file);
+				}
+				break;
+			case 'HORIZONTAL_BOX_PLOT':
+				$graph = new pts_HorizontalBoxPlotGraph($result_object, $result_file);
 				break;
 			case 'BAR_ANALYZE_GRAPH':
 			case 'BAR_GRAPH':
@@ -233,9 +240,9 @@ class pts_render
 		{
 			$graph->markResultRegressions($extra_attributes['regression_marker_threshold']);
 		}
-		if(isset($extra_attributes['set_alternate_location']))
+		if(isset($extra_attributes['set_alternate_view']))
 		{
-			$graph->setAlternateLocation($extra_attributes['set_alternate_location']);
+			$graph->setAlternateView($extra_attributes['set_alternate_view']);
 		}
 		if(isset($extra_attributes['sort_result_buffer_values']))
 		{
@@ -278,6 +285,20 @@ class pts_render
 					$graph->loadGraphIdentifiers($ss);
 				}
 				break;
+			case 'HORIZONTAL_BOX_PLOT':
+				// TODO: should be able to load pts_test_result_buffer_item objects more cleanly into pts_Graph
+				$identifiers = array();
+				$values = array();
+
+				foreach($result_object->test_result_buffer->get_buffer_items() as $buffer_item)
+				{
+					array_push($identifiers, $buffer_item->get_result_identifier());
+					array_push($values, pts_strings::comma_explode($buffer_item->get_result_value()));
+				}
+
+				$graph->loadGraphIdentifiers($identifiers);
+				$graph->loadGraphValues($values);
+				break;
 			default:
 				// TODO: should be able to load pts_test_result_buffer_item objects more cleanly into pts_Graph
 				$identifiers = array();
@@ -528,10 +549,17 @@ class pts_render
 		else
 		{
 			$mto->test_profile->set_result_scale($mto->test_profile->get_result_scale() . ' | ' . implode(',', array_keys($days)));
-			if($mto->test_profile->get_display_format() != 'SCATTER_PLOT')
+
+			switch($mto->test_profile->get_display_format())
 			{
-				$line_graph_type = isset($extra_attributes['filled_line_graph']) ? 'FILLED_LINE_GRAPH' : 'LINE_GRAPH';
-				$mto->test_profile->set_display_format((count($days) < 5 || ($is_tracking == false && !isset($extra_attributes['force_line_graph_compact'])) ? 'BAR_ANALYZE_GRAPH' : $line_graph_type));
+				//case 'HORIZONTAL_BOX_PLOT':
+				//	$mto->test_profile->set_display_format('HORIZONTAL_BOX_PLOT_MULTI');
+				//	break;
+				case 'SCATTER_PLOT';
+					break;
+				default:
+					$line_graph_type = isset($extra_attributes['filled_line_graph']) ? 'FILLED_LINE_GRAPH' : 'LINE_GRAPH';
+					$mto->test_profile->set_display_format((count($days) < 5 || ($is_tracking == false && !isset($extra_attributes['force_line_graph_compact'])) ? 'BAR_ANALYZE_GRAPH' : $line_graph_type));
 			}
 
 			foreach(array_keys($systems) as $system_key)
@@ -567,6 +595,11 @@ class pts_render
 	}
 	public static function multi_way_identifier_check($identifiers, &$system_hardware = null, &$result_file = null)
 	{
+		/*
+			Samples To Use For Testing:
+			1109026-LI-AMDRADEON57
+		*/
+
 		$systems = array();
 		$targets = array();
 		$is_multi_way = true;
