@@ -23,11 +23,16 @@
 class pts_test_install_manager
 {
 	private $tests_to_install;
+	private static $extra_caches = array();
 
 	public function __construct()
 	{
 		$this->tests_to_install = array();
 	}
+	public static function add_external_download_cache($cache)
+	{
+		return !in_array($cache, self::$extra_caches) ? array_push(self::$extra_caches, $cache) : false;
+	}
 	public function add_test_profile($test_profile)
 	{
 		$added = false;
@@ -97,7 +102,7 @@ class pts_test_install_manager
 
 		return $remote_download_files;
 	}
-	public function remote_download_caches()
+	public static function remote_download_caches()
 	{
 		$cache_directories = array();
 
@@ -111,7 +116,7 @@ class pts_test_install_manager
 
 		return $cache_directories;
 	}
-	public function local_download_caches()
+	public static function local_download_caches()
 	{
 		$local_cache_directories = array();
 
@@ -159,7 +164,7 @@ class pts_test_install_manager
 			// User Defined Directory Checking
 			$dir_string = ($dir = pts_client::read_env('PTS_DOWNLOAD_CACHE')) != false ? $dir : null;
 
-			foreach(pts_strings::colon_explode($dir_string) as $dir_check)
+			foreach(array_merge(self::$extra_caches, pts_strings::colon_explode($dir_string)) as $dir_check)
 			{
 				if($dir_check == null)
 				{
