@@ -48,10 +48,6 @@ class pts_test_run_manager
 	private $dynamic_run_count_std_deviation_threshold;
 	private $dynamic_run_count_export_script;
 
-	// These variables could potentially be cleaned up or eliminated
-	private $results_directory;
-	private $wrote_system_xml;
-
 	private static $test_run_process_active = false;
 
 	public function __construct($test_flags = 0)
@@ -682,17 +678,11 @@ class pts_test_run_manager
 		if($this->do_save_results())
 		{
 			$this->result_file_setup();
-			$this->results_directory = pts_client::setup_test_result_directory($this->get_file_name()) . '/';
 
 			if((pts_c::$test_flags ^ pts_c::is_recovering) && (!pts_result_file::is_test_result_file($this->get_file_name()) || $this->result_already_contains_identifier() == false))
 			{
 				$this->result_file_writer->add_result_file_meta_data($this);
 				$this->result_file_writer->add_current_system_information();
-				$this->wrote_system_xml = true;
-			}
-			else
-			{
-				$this->wrote_system_xml = false;
 			}
 
 			$pso = new pts_storage_object(true, false);
@@ -701,7 +691,7 @@ class pts_test_run_manager
 			$pso->add_object('system_hardware', phodevi::system_hardware(false));
 			$pso->add_object('system_software', phodevi::system_software(false));
 
-			$pso->save_to_file($this->results_directory . 'objects.pt2so');
+			$pso->save_to_file(pts_client::setup_test_result_directory($this->get_file_name()) . '/objects.pt2so');
 			unset($pso);
 		}
 	}
@@ -715,10 +705,10 @@ class pts_test_run_manager
 				return false;
 			}
 
-			pts_file_io::unlink($this->results_directory . 'objects.pt2so');
+			pts_file_io::unlink(pts_client::setup_test_result_directory($this->get_file_name()) . '/objects.pt2so');
 			pts_file_io::delete(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/active/', null, true);
 
-			if($this->wrote_system_xml)
+			if((pts_c::$test_flags ^ pts_c::is_recovering) && (!pts_result_file::is_test_result_file($this->get_file_name()) || $this->result_already_contains_identifier() == false))
 			{
 				$this->result_file_writer->add_test_notes(pts_test_notes_manager::generate_test_notes($this->tests_to_run));
 			}
@@ -740,10 +730,14 @@ class pts_test_run_manager
 				{
 					$upload_results = pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/UploadResults', 'TRUE');
 				}
-				else
+				else if((pts_c::$test_flags ^ pts_c::auto_mode))
 				{
 					$upload_results = pts_user_io::prompt_bool_input('Would you like to upload these results to OpenBenchmarking.org', true);
 				}
+				else
+				{
+					$upload_results = false;
+				}
 
 				if($upload_results)
 				{
@@ -769,7 +763,7 @@ class pts_test_run_manager
 
 		foreach($to_run_objects as &$run_object)
 		{
-			if($skip_tests && (in_array($run_object->get_identifier(false), $skip_tests) || in_array($run_object->get_identifier_base_name(), $skip_tests)))
+			if($skip_tests && (in_array($run_object->get_identifier(false), $skip_tests) || ($run_object instanceof pts_test_profile && in_array($run_object->get_identifier_base_name(), $skip_tests))))
 			{
 				echo 'Skipping: ' . $run_object->get_identifier() . PHP_EOL;
 				continue;
@@ -896,7 +890,11 @@ class pts_test_run_manager
 	{
 		$this->set_save_name($save_name, false);
 		$this->set_results_identifier($result_identifier);
-		$this->run_description = $description;
+		$this->set_description($description);
+	}
+	public function set_description($description)
+	{
+		$this->run_description = $description == null ? self::auto_generate_description() : $description;
 	}
 	protected function auto_generate_description()
 	{
@@ -923,7 +921,7 @@ class pts_test_run_manager
 			$existing_identifier_count = 0;
 		}
 
-		$auto_description = 'Running ' . implode(', ', array_unique($this->get_tests_to_run_identifiers())) . ' via the Phoronix Test Suite.';
+		$auto_description = 'Running ' . implode(', ', array_unique($this->get_tests_to_run_identifiers()));
 		$subsystems_to_test = array();
 
 		foreach($this->tests_to_run as $test_run_request)
@@ -933,27 +931,50 @@ class pts_test_run_manager
 		$subsystems_to_test = array_unique($subsystems_to_test);
 
 		// TODO: hook into $hw_components and $sw_components for leveraging existing result file data for comparisons already in existent
-		if(count($subsystems_to_test) == 1 && $existing_identifier_count == 0)
+		// dropped: count($subsystems_to_test) == 1 && $
+		if($existing_identifier_count == 0)
 		{
 			switch($subsystems_to_test)
 			{
 				case 'Graphics':
-					$auto_description = phodevi::read_property('gpu', 'model') . ' graphics testing with ' . phodevi::read_property('system', 'display-driver-string') . ' / ' . phodevi::read_property('system', 'opengl-driver') . ' via the Phoronix Test Suite.';
+					$auto_description = phodevi::read_property('gpu', 'model') . ' graphics testing with ' . phodevi::read_property('system', 'display-driver-string') . ' / ' . phodevi::read_property('system', 'opengl-driver');
 					break;
 				case 'Disk':
-					$auto_description = phodevi::read_name('disk') . ' testing on ' . phodevi::read_property('system', 'operating-system') . ' with a ' . phodevi::read_property('system', 'filesystem') . ' file-system via the Phoronix Test Suite.';
+					$auto_description = phodevi::read_name('disk') . ' testing on ' . phodevi::read_property('system', 'operating-system') . ' with a ' . phodevi::read_property('system', 'filesystem') . ' file-system';
 					break;
+				case 'Memory':
 				case 'Processor':
+					$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' on ' . phodevi::read_property('system', 'operating-system');
+					break;
 				default:
-					$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' under ' . phodevi::read_property('system', 'operating-system') . ' via the Phoronix Test Suite.';
+					$auto_description = phodevi::read_property('cpu', 'model') . ' testing with a ' . phodevi::read_name('motherboard') . ' and ' . phodevi::read_property('gpu', 'model') . ' on ' . phodevi::read_property('system', 'operating-system');
 					break;
 			}
 		}
+		else
+		{
+			if(pts_result_file::is_test_result_file($this->file_name))
+			{
+				$result_file = new pts_result_file($this->file_name);
+				$result_file_intent = pts_result_file_analyzer::analyze_result_file_intent($result_file);
+
+				if(is_array($result_file_intent) && $result_file_intent[0] != 'Unknown')
+				{
+					$auto_description = 'A ' . $result_file_intent[0] . ' comparison';
+				}
+			}
+		}
+
+		$auto_description .= ' via the Phoronix Test Suite.';
 
 		return $auto_description;
 	}
 	public function save_results_prompt()
 	{
+		pts_client::$display->generic_heading('System Information');
+		echo 'Hardware:' . PHP_EOL . phodevi::system_hardware(true) . PHP_EOL . PHP_EOL;
+		echo 'Software:' . PHP_EOL . phodevi::system_software(true) . PHP_EOL . PHP_EOL;
+
 		if(($this->prompt_save_results || $this->force_save_results) && count($this->tests_to_run) > 0) // or check for DO_NOT_SAVE_RESULTS == false
 		{
 			if($this->force_save_results || pts_client::read_env('TEST_RESULTS_NAME'))
@@ -1244,7 +1265,7 @@ class pts_test_run_manager
 	{
 		$valid_test_profile = true;
 		$test_type = $test_profile->get_test_hardware_type();
-		$skip_tests = pts_client::read_env('SKIP_TESTS');
+		$skip_tests = pts_client::read_env('SKIP_TESTS') ? pts_strings::comma_explode(pts_client::read_env('SKIP_TESTS')) : false;
 		$display_driver = phodevi::read_property('system', 'display-driver');
 
 		if($test_profile->is_supported(false) == false)
@@ -1266,7 +1287,7 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('Running on a RAM-based live file-system, cannot run ' . $test_profile);
 			$valid_test_profile = false;
 		}
-		else if(pts_client::read_env('NO_' . strtoupper($test_type) . '_TESTS') || ($skip_tests && in_array($test_profile, pts_strings::comma_explode($skip_tests))) || ($skip_tests && in_array($test_type, pts_strings::comma_explode($skip_tests))))
+		else if(pts_client::read_env('NO_' . strtoupper($test_type) . '_TESTS') ||($skip_tests && (in_array($test_profile, $skip_tests) || in_array($test_type, $skip_tests) || in_array($test_profile->get_identifier(false), $skip_tests) || in_array($run_object->get_identifier_base_name(), $skip_tests))))
 		{
 			$report_errors && pts_client::$display->test_run_error('Due to a pre-set environmental variable, skipping ' . $test_profile);
 			$valid_test_profile = false;
