@@ -108,7 +108,7 @@ class pts_user_io
 
 		if($option_count == 1)
 		{
-			return $return_index ? array_pop(array_keys($options_r)) : array_pop($options_r);
+			return $return_index ? pts_arrays::last_element(array_keys($options_r)) : array_pop($options_r);
 		}
 
 		$select = array();
