@@ -21,7 +21,10 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-setlocale(LC_NUMERIC, 'C');
+if(defined('LC_NUMERIC'))
+{
+	setlocale(LC_NUMERIC, 'C');
+}
 define('PTS_PATH', dirname(dirname(__FILE__)) . '/');
 
 // PTS_MODE types
@@ -33,26 +36,6 @@ define('PTS_MODE', in_array(($m = getenv('PTS_MODE')), array('CLIENT', 'LIB', 'S
 // Any PHP default memory limit should be fine for PTS, until you run image quality comparison tests that begins to consume memory
 ini_set('memory_limit', '256M');
 
-if(PTS_MODE == 'CLIENT' && ($open_basedir = ini_get('open_basedir')))
-{
-	$is_in_allowed_dir = false;
-
-	foreach(explode(':', $open_basedir) as $allowed_dir)
-	{
-		if(strpos(PTS_PATH, $allowed_dir) === 0)
-		{
-			$is_in_allowed_dir = true;
-			break;
-		}
-	}
-
-	if($is_in_allowed_dir == false)
-	{
-		echo PHP_EOL . 'ERROR: Your php.ini configuration open_basedir setting is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
-		return false;
-	}
-}
-
 require(PTS_PATH . 'pts-core/pts-core.php');
 
 if(PTS_MODE != 'CLIENT')
@@ -66,6 +49,15 @@ if(ini_get('date.timezone') == null)
 	date_default_timezone_set('UTC');
 }
 
+if(ini_get('open_basedir') != false)
+{
+	if(pts_client::open_basedir_check() == false)
+	{
+		echo PHP_EOL . 'ERROR: Your php.ini configuration open_basedir setting is preventing ' . PTS_PATH . ' from loading.' . PHP_EOL;
+		return false;
+	}
+}
+
 // Needed for shutdown functions
 // declare(ticks = 1);
 
@@ -76,7 +68,6 @@ define('QUICK_START', in_array($sent_command, $quick_start_options));
 pts_client::program_requirement_checks(true);
 pts_client::init(); // Initalize the Phoronix Test Suite (pts-core) client
 $pass_args = array();
-//stream_wrapper_register('phoronix', 'pts_phoronix_stream') or die('Failed To Initialize The Phoronix Stream');
 
 if(is_file(PTS_PATH . 'pts-core/commands/' . $sent_command . '.php') == false)
 {
@@ -95,18 +86,16 @@ if(is_file(PTS_PATH . 'pts-core/commands/' . $sent_command . '.php') == false)
 	}
 	else
 	{
-		$alias_file = pts_file_io::file_get_contents(PTS_CORE_STATIC_PATH . 'lists/option-command-aliases.list');
-
-		foreach(pts_strings::trim_explode("\n", $alias_file) as $alias_line)
+		$aliases = pts_storage_object::read_from_file(PTS_TEMP_STORAGE, 'command_alias_list');
+		if($aliases == null)
 		{
-			list($link_cmd, $real_cmd) = pts_strings::trim_explode('=', $alias_line);
+			$aliases = pts_documentation::client_commands_aliases();
+		}
 
-			if($link_cmd == $sent_command)
-			{
-				$sent_command = $real_cmd;
-				$replaced = true;
-				break;
-			}
+		if(isset($aliases[$sent_command]))
+		{
+			$sent_command = $aliases[$sent_command];
+			$replaced = true;
 		}
 	}
 
@@ -119,7 +108,7 @@ if(is_file(PTS_PATH . 'pts-core/commands/' . $sent_command . '.php') == false)
 
 define('PTS_USER_LOCK', PTS_USER_PATH . 'run_lock');
 
-if(!QUICK_START)
+if(QUICK_START == false)
 {
 	if(pts_client::create_lock(PTS_USER_LOCK) == false)
 	{
@@ -128,50 +117,7 @@ if(!QUICK_START)
 
 	register_shutdown_function(array('pts_client', 'process_shutdown_tasks'));
 
-	if(($proxy_address = pts_config::read_user_config('PhoronixTestSuite/Options/Networking/ProxyAddress', false)) && ($proxy_port = pts_config::read_user_config('PhoronixTestSuite/Options/Networking/ProxyPort', false)))
-	{
-		define('NETWORK_PROXY', $proxy_address . ':' . $proxy_port);
-		define('NETWORK_PROXY_ADDRESS', $proxy_address);
-		define('NETWORK_PROXY_PORT', $proxy_port);
-	}
-	else if(($env_proxy = getenv('http_proxy')) != false && count($env_proxy = pts_strings::colon_explode($env_proxy)) == 2)
-	{
-		define('NETWORK_PROXY', $env_proxy[0] . ':' . $env_proxy[1]);
-		define('NETWORK_PROXY_ADDRESS', $env_proxy[0]);
-		define('NETWORK_PROXY_PORT', $env_proxy[1]);
-	}
-
-	define('NETWORK_TIMEOUT', pts_config::read_user_config('PhoronixTestSuite/Options/Networking/Timeout', 20));
-
-	if(ini_get('allow_url_fopen') == 'Off')
-	{
-		echo PHP_EOL . 'The allow_url_fopen option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
-		define('NO_NETWORK_COMMUNICATION', true);
-	}
-	else if(pts_config::read_bool_config('PhoronixTestSuite/Options/Networking/NoNetworkCommunication', 'FALSE'))
-	{
-		define('NO_NETWORK_COMMUNICATION', true);
-		echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
-	}
-	else if(pts_flags::no_network_communication() == true)
-	{
-		define('NO_NETWORK_COMMUNICATION', true);
-		//echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
-	}
-	/* else
-	{
-		$server_response = pts_network::http_get_contents('http://www.phoronix-test-suite.com/PTS', false, false);
-
-		if($server_response != 'PTS')
-		{
-			define('NO_NETWORK_COMMUNICATION', true);
-		}
-	}*/
-
-	if(!defined('NO_NETWORK_COMMUNICATION') && ini_get('file_uploads') == 'Off')
-	{
-		echo PHP_EOL . 'The file_uploads option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
-	}
+	pts_network::client_startup();
 
 	if(pts_client::read_env('PTS_IGNORE_MODULES') == false)
 	{
@@ -196,7 +142,7 @@ if(QUICK_START == false)
 
 pts_client::execute_command($sent_command, $pass_args); // Run command
 
-if(!QUICK_START)
+if(QUICK_START == false)
 {
 	pts_client::release_lock(PTS_USER_LOCK);
 }
