@@ -21,17 +21,17 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define('PTS_VERSION', '3.2.1');
-define('PTS_CORE_VERSION', 3210);
-define('PTS_CODENAME', 'GRIMSTAD');
-define('PTS_IS_CLIENT', PTS_MODE == 'CLIENT');
+define('PTS_VERSION', '3.4.0');
+define('PTS_CORE_VERSION', 3400);
+define('PTS_CODENAME', 'LILLESAND');
+define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
 
-/*
-if(PTS_IS_CLIENT)
+
+if(PTS_IS_CLIENT && substr(PTS_VERSION, -2, 1) == 'm')
 {
+	// Enable more verbose error reporting only when PTS is in development with milestone (alpha/beta) releases but no release candidate (r) or gold versions
 	error_reporting(E_ALL | E_NOTICE | E_STRICT);
 }
-*/
 
 function pts_codename($full_string = false)
 {
@@ -52,6 +52,7 @@ function pts_define_directories()
 	{
 		define('PTS_USER_PATH', pts_client::user_home_directory() . '.phoronix-test-suite/');
 		define('PTS_CORE_STORAGE', PTS_USER_PATH . 'core.pt2so');
+		define('PTS_TEMP_STORAGE', PTS_USER_PATH . 'temp.pt2so');
 	}
 
 	// Misc Locations
@@ -76,9 +77,9 @@ function pts_needed_extensions()
 		// Required? - The Check If In Place - Name - Description
 
 		// Required extesnions denoted by 1 at [0]
-		array(1, extension_loaded('dom'), 'DOM', 'The PHP Document Object Model (DOM) is required.'),
-		array(1, extension_loaded('zip') || extension_loaded('zlib'), 'ZIP', 'PHP Zip support is required.'),
-		array(1, function_exists('json_decode'), 'JSON', 'PHP JSON support is required.'),
+		array(1, extension_loaded('dom'), 'DOM', 'The PHP Document Object Model (DOM) is required for XML operations.'),
+		array(1, extension_loaded('zip') || extension_loaded('zlib'), 'ZIP', 'PHP Zip support is required for file compression and decompression.'),
+		array(1, function_exists('json_decode'), 'JSON', 'PHP JSON support is required for OpenBenchmarking.org communication.'),
 
 		// Optional but recommended extensions
 		array(0, extension_loaded('openssl'), 'OpenSSL', 'PHP OpenSSL support is recommended to support HTTPS traffic.'),
@@ -86,37 +87,48 @@ function pts_needed_extensions()
 		array(0, extension_loaded('zlib'), 'Zlib', 'The PHP Zlib extension can be used for greater file compression.'),
 		array(0, function_exists('pcntl_fork'), 'PCNTL', 'PHP PCNTL is highly recommended as it is required by some tests.'),
 		array(0, function_exists('posix_getpwuid'), 'POSIX', 'PHP POSIX support is highly recommended.'),
-		array(0, function_exists('curl_init'), 'CURL', 'PHP CURL is recommended for a better download experience.')
-
-		// PHP FPDF could be added here too...
+		array(0, function_exists('curl_init'), 'CURL', 'PHP CURL is recommended for an enhanced download experience.'),
+		array(0, is_file('/usr/share/php/fpdf/fpdf.php'), 'PHP FPDF', 'PHP FPDF is recommended if wishing to generate PDF reports.')
 		);
 }
 
 if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 {
-	function __autoload($to_load)
+	function pts_build_dir_php_list($dir, &$files)
 	{
-		static $sub_objects = null;
-
-		if($sub_objects == null)
+		if($dh = opendir($dir))
 		{
-			$sub_objects = array();
-
-			foreach(array_merge(glob(PTS_PATH . 'pts-core/objects/*/*.php'), glob(PTS_PATH . 'pts-core/objects/*/*/*.php')) as $file)
+			while(($file = readdir($dh)) !== false)
 			{
-				$object_name = basename($file, '.php');
-				$sub_objects[$object_name] = $file;
+				if($file != '.' && $file != '..')
+				{
+					if(is_dir($dir . '/' . $file))
+					{
+						pts_build_dir_php_list($dir . '/' . $file, $files);
+					}
+					else if(substr($file, -4) == '.php')
+					{
+						$files[substr($file, 0, -4)] = $dir . '/' . $file;
+					}
+				}
 			}
 		}
 
-		if(is_file(PTS_PATH . 'pts-core/objects/' . $to_load . '.php'))
+		closedir($dh);
+	}
+	function __autoload($to_load)
+	{
+		static $obj_files = null;
+
+		if($obj_files == null)
 		{
-			include(PTS_PATH . 'pts-core/objects/' . $to_load . '.php');
+			pts_build_dir_php_list(PTS_PATH . 'pts-core/objects', $obj_files);
 		}
-		else if(isset($sub_objects[$to_load]))
+
+		if(isset($obj_files[$to_load]))
 		{
-			include($sub_objects[$to_load]);
-			unset($sub_objects[$to_load]);
+			include($obj_files[$to_load]);
+			unset($obj_files[$to_load]);
 		}
 	}
 }
